package net.pricefx.formulaengine.scripting;

import java.util.Collection;
import java.util.List;
import java.util.Map;

/**
 * ClaimContext is used for configuration of
 * <a href="https://pricefx.atlassian.net/wiki/display/HELP/ChannelManager">Channel Manager</a>.
 *
 * Instance can be obtained via call <code>api.getClaimContext()</code>
 * <p><b>Example:</b></p>
 * <blockquote>
 *     <pre>
 *         def productId = api.getClaimContext().getRow().get("MATERIAL")
 *     </pre>
 * </blockquote>
 * @see PublicGroovyAPI#getClaimContext()
 */
public interface ClaimContext {
    /**
     * Get parsed row from excel claim input.
     *
     * @return Map of header name –&gt; cell value
     */
    Map<String, Object> getRow();

	/**
	 * Get line item typed id in Allocation Formula only
	 *
	 * @return typedId of the selected item
	 */
	String getLineItemTypedId();

	/**
     * Set row for formula testdrive
     *
     * @param debugRow for debugging
     */
    void setDebugRow(Map<String, Object> debugRow);

    /**
     * Get name of the attribute based on Claim Type configuration to which the column gets persisted
     *
     * @return "attributeX"
     */
    String getAttributeName(String columnName);

	/**
	 * Set data from which a claim can be created
	 *
	 * @param headerValues Claim header fields' values
	 * @param columnNames Names of columns (keys from a sample row)
	 * @param data Table (list of maps), where each map is a columnName -&gt; value
	 */
	void setNewClaimData(Map<String, Object> headerValues, Collection<String> columnNames, List<Map<String, Object>> data);
}
